pilot.api.api.ComputeDataService

Package pilot :: Package api :: Module api :: Class ComputeDataService |

# Class ComputeDataService

source code

ComputeDataService (CDS).

The ComputeDataService is the application's interface to submit ComputeUnits and PilotData/DataUnit to the Pilot-Manager in the P* Model.

Instance Methods
__init__(self, wds_id=None) Create a Compute Data Service object. | source code
add_pilot_job_service(self, pjs) Add a PilotComputeService to this WUS. (Inherited from pilot.api.compute.api.ComputeUnitService) | source code
cancel(self) Cancel the WUS. (Inherited from pilot.api.compute.api.ComputeUnitService) | source code
create_pilot(self, pilot_data_description) Create a PilotData (Inherited from pilot.api.data.api.PilotDataService) | source code
get_id(self) (Inherited from pilot.api.compute.api.ComputeUnitService) | source code
get_state(self) (Inherited from pilot.api.compute.api.ComputeUnitService) | source code
list_pilots(self) List all PDs of PDS (Inherited from pilot.api.data.api.PilotDataService) | source code
remove_pilot_job_service(self, pjs) Remove a PilotComputeService from this WUS. (Inherited from pilot.api.compute.api.ComputeUnitService) | source code
submit_compute_unit(self, wud) Submit a WU to this Work Unit Service. (Inherited from pilot.api.compute.api.ComputeUnitService) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
| id (Inherited from pilot.api.data.api.PilotDataService)
| pilot_data (Inherited from pilot.api.data.api.PilotDataService)
| state (Inherited from pilot.api.data.api.PilotDataService)
Inherited from `object`: `__class__`

Method Details

### __init__(self, wds_id=None) (Constructor) | source code
Create a Compute Data Service object. Keyword arguments: wds_id -- Reconnect to an existing WDS (optional). Overrides: object.__init__